@@ -1,24 +1,25 @@
 #' @param MSV  value to replace na with, same used for every column used
-#' @param Plot_Name  plot identifier
-#' @param Plot_Type  list of parameters controlling the plot options
+#' @param Plot_Name  plot identifier, used in filename for saved plots
+#' @param Plot_Type  list of parameters controlling the plot options: surv, risk, schoenfeld
 #' @param Strat_Col  column to stratify by if needed
-#' @param Strat_Cols  column to stratify by
 #' @param Term_n  term numbers for each element of the model
 #' @param a0  linear slope
 #' @param a1_goal  exponential maximum desired
 #' @param a_n  list of initial parameter values, used to determine number of parameters
 #' @param age_unit  age unit
-#' @param alternative_model  the new model of interest
+#' @param alternative_model  the new model of interest in list form
 #' @param b  optimum parameter values used
-#' @param ce  columns to check for truncation
+#' @param ce  columns to check for truncation, (t0, t1, event)
 #' @param cens_weight  list of weights for censoring rate
 #' @param ch  cumulative hazards of baseline
 #' @param col_list  an array of column names that should have factor terms defined
-#' @param col_name  new column name
+#' @param col_name  vector of new column names
 #' @param cols  columns to check
-#' @param control  list of parameters controlling the convergence
+#' @param control  list of parameters controlling the convergence, see Def_Control() for options or vignette("starting_description")
+#' @param Cons_Mat Matrix containing coefficients for system of linear constraints, formatted as matrix
+#' @param Cons_Vec Vector containing constants for system of linear constraints, formatted as vector
 #' @param dep_cols  columns that are not needed in the new dataframe
-#' @param der_iden  number for the subterm to test derivative at, only used for testing runs with a single varying parameter
+#' @param der_iden  number for the subterm to test derivative at, only used for testing runs with a single varying parameter, should be smaller than total number of parameters
 #' @param df  a data.table containing the columns of interest
 #' @param dnames  list of covariate columns to plot by
 #' @param dt  spacing in time for new rows
@@ -29,21 +30,21 @@
 #' @param fir  term number for the initial term, used for models of the form T0*f(Ti) in which the order matters
 #' @param fname  filename used for new dataframe
 #' @param func_form  vector of functions to apply to each time-dependent covariate. Of the form func(df, time) returning a vector of the new column value
-#' @param guesses_control  list of parameters to control how the guessing works
+#' @param guesses_control  list of parameters to control how the guessing works, see Def_Control_Guess() for options or vignette("Alt_Distrib_Starts")
 #' @param h  hazards of baseline
-#' @param interactions  array of strings, each one is of form term1?*?term2" for term1 interaction of type * with term2, "?" dlimits
-#' @param iscox  boolean if rows not at event times should be kept
+#' @param interactions  array of strings, each one is of form term1?*?term2" for term1 interaction of type * or + with term2, "?" dlimits
+#' @param iscox  boolean if rows not at event times should be kept, rows are removed if true
 #' @param keep_constant  binary values to denote which parameters to change
-#' @param model_control  controls which alternative model options are used
-#' @param modelform  string specifying the model type
+#' @param model_control  controls which alternative model options are used, see Def_model_control() for options and vignette("Alt_Run_opt") for further details
+#' @param modelform  string specifying the model type: M, ME, A, PA, PAE, GMIX, GMIX-R, GMIX-E
 #' @param name_list  vector of string column names to check
 #' @param names  columns for elements of the model, used to identify data columns
 #' @param new_names  list of new names to use instead of default, default used if entry is ''
-#' @param nthreads  number of threads to use
-#' @param null_model  a model to compare against
+#' @param nthreads  number of threads to use, do not use more threads than available on your machine
+#' @param null_model  a model to compare against, in list form
 #' @param paras  list of formula parameters
-#' @param plot_options  list of parameters controlling the plot options
-#' @param pyr  column used for person-years per row
+#' @param plot_options  list of parameters controlling the plot options, see RunCoxPlots() for different options
+#' @param pyr0  column used for person-years per row
 #' @param studyID  id to group by, NaN for no grouping
 #' @param surv  survival fraction of baseline
 #' @param t  event times
@@ -56,8 +57,8 @@
 #' @param tref  reference time in date format
 #' @param tu  unique event times
 #' @param units  time unit to use
-#' @param verbose  boolean to control if additional information is printed to the console
-#' @param verbosec  boolean identifying if extra regression information should be written to the console
+#' @param verbose  boolean to control if additional information is printed to the console, also accepts 0/1 integer
+#' @param verbosec  boolean identifying if extra regression information should be written to the console, also accepts 0/1 integer
 #' @param y  point formula switch
 #'
 #' @name R_template
@@ -111,6 +112,9 @@ NULL
 #' @param change_all  boolean if every parameter is being updated
 #' @param colToRemove  column index to remove
 #' @param cols  list of column identifiers, single continuous list
+#' @param constraint_bool  boolean for system of linear equality constraints used
+#' @param Cons_Mat Matrix containing coefficients for system of linear constraints
+#' @param Cons_Vec Vector containing constants for system of linear constraints
 #' @param dbeta  parameter change vector
 #' @param dbeta_cap  learning rate for newton step toward 0 log-likelihood
 #' @param debugging  additional boolean for verbosity in testing
@@ -140,6 +144,8 @@ NULL
 #' @param halfmax  maximum number of half steps
 #' @param iscox  boolean of cox formatting is used
 #' @param iter_stop  binary value used to tell the function not to continue iteration
+#' @param Lin_Res Vector containing constants for system of linear constraints
+#' @param Lin_Sys Matrix containing coefficients for system of linear constraints
 #' @param lr  learning rate for newton step toward 0 derivative
 #' @param matrix_modify matrix to remove rows or columns from 
 #' @param maxiter   integer of maximum number of iterations
@@ -174,3 +180,18 @@ NULL
 #'
 #' @name CPP_template
 NULL
+
+#' @importFrom Rcpp evalCpp
+#' @importFrom data.table data.table fread setkeyv copy setorderv setnames as.data.table set := .SD
+#' @importFrom parallel detectCores
+#' @importFrom stats runif
+#' @importFrom utils combn head
+#' @importFrom grDevices colorRampPalette dev.off jpeg
+#' @importFrom graphics legend lines smoothScatter
+#' @importFrom stats approxfun time qchisq
+#' @importFrom rlang .data
+#' @useDynLib Colossus, .registration = TRUE
+NULL
+
+
+
